@@ -5,7 +5,7 @@ from touchandgo.helpers import get_interface
 
 
 class Output(object):
-    def __init__(self, stream_url, sub_file=None, parent=None):
+    def __init__(self, stream_url, sub_file, parent):
         self.stream_url = stream_url
         self.sub_file = sub_file
         self.parent = parent
@@ -48,31 +48,14 @@ class OMXOutput(Output):
 class CastOutput(Output):
     def run(self):
         import pychromecast
-        from pychromecast.controllers.media import MediaController
 
         self.chromecast = pychromecast.get_chromecast()
         interface = get_interface()
-        guess = {"mimetype": "video/mp4"} #self.parent.guess(self.parent.get_video_path())
-
-        class Controller(MediaController):
-            def receive_message(self, message, data):
-                print message, data
-                return True
-
-        handler = Controller()
-        self.chromecast.register_handler(handler)
-        handler.play_media("http://%s:%s" % (interface, 8888), #self.parent.port),
+        guess = self.parent.guess(self.parent.get_video_path())
+        self.chromecast.play_media("http://%s:%s" % (interface, self.parent.port),
                                    guess['mimetype'])
         while True:
-            print("Media status", self.chromecast.media_controller._status_listeners)
             sleep(1)
 
-
     def __del__(self):
         self.chromecast.media_controller.stop()
-
-
-if __name__ == "__main__":
-    from logger import log_setup
-    log_setup(True)
-    CastOutput("http://localhost:8080", None, None).run()
