@@ -19,19 +19,20 @@ class SubtitleDownloader(object):
         self.lang = sub_lang
 
     def download(self, video_file):
+        subtitle = None
         settings = get_settings()
         download_dir = settings['save_path']
-        print("Downloading subtitle")
         log.info("Downloading subtitle")
         filepath = join(download_dir, video_file[0])
         guess = guess_video_info(filepath, info=['filename'])
         video = Video.fromguess(filepath, guess)
         video.size = video_file[1]
-        subtitle = download_best_subtitles([video], {Language(self.lang)},
-                                           single=True)
-        if not len(subtitle):
-            subtitle = None
-        else:
+        try:
+            subtitle = download_best_subtitles([video], {Language(self.lang)},
+                                               single=True)
+        except ValueError:
+            pass
+        if subtitle is not None and len(subtitle):
             subtitle = get_subtitle_path(join(download_dir, video.name))
         log.info("video_file: %s, filepath: %s, guess: %s, video: %s"
                  "subtitle: %s", video_file, filepath, guess, video, subtitle)
